from setuptools import setup, find_packages

# Setting Up

setup(
      
      name = "anaplan",
      version = "1.0.1",
      author = "Hasan Can Beydili",
      author_email = "tchasancan@gmail.com",
      description= "PyerualJetwork --> Anaplan (Name Change)",
      packages = find_packages(),
      keywords = ["model evaluation", "classifcation", 'potentiation learning artficial neural networks'],

      
      )